summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/src/tiered/tiered_handle.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/third_party/wiredtiger/src/tiered/tiered_handle.c')
-rw-r--r--src/third_party/wiredtiger/src/tiered/tiered_handle.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/third_party/wiredtiger/src/tiered/tiered_handle.c b/src/third_party/wiredtiger/src/tiered/tiered_handle.c
index a673e71832d..f7b7e42d1e8 100644
--- a/src/third_party/wiredtiger/src/tiered/tiered_handle.c
+++ b/src/third_party/wiredtiger/src/tiered/tiered_handle.c
@@ -296,8 +296,8 @@ __tiered_restart_work(WT_SESSION_IMPL *session, WT_TIERED *tiered)
* flushed in order to stop at the first flushed object in the face of multiple crashes. So
* check all objects that exist locally.
*
* If the object is flushed but still exists locally, restart the work to drop it after the
* local retention period expires.
*/
if (exist) {
WT_ERR(__wt_metadata_search(session, obj_uri, (char **)&obj_val));
@@ -307,7 +307,7 @@ __tiered_restart_work(WT_SESSION_IMPL *session, WT_TIERED *tiered)
if (cval.val == 0)
WT_ERR(__wt_tiered_put_flush(session, tiered, i));
else
- WT_ERR(__wt_tiered_put_drop_local(session, tiered, i));
+ WT_ERR(__wt_tiered_put_remove_local(session, tiered, i));
__wt_free(session, obj_val);
}
__wt_free(session, obj_uri);
@@ -785,8 +785,8 @@ __tiered_open(WT_SESSION_IMPL *session, const char *cfg[])
/* Temp code to keep s_all happy. */
FLD_SET(unused, WT_TIERED_OBJ_LOCAL | WT_TIERED_TREE_UNUSED);
FLD_SET(unused, WT_TIERED_WORK_FORCE | WT_TIERED_WORK_FREE);
- WT_ERR(__wt_tiered_put_drop_shared(session, tiered, tiered->current_id));
- __wt_tiered_get_drop_shared(session, &entry);
+ WT_ERR(__wt_tiered_put_remove_shared(session, tiered, tiered->current_id));
+ __wt_tiered_get_remove_shared(session, &entry);
}
#endif
@@ -296,8 +296,8 @@ __tiered_restart_work(WT_SESSION_IMPL *session, WT_TIERED *tiered)
* check all objects that exist locally.
*
- * If the object is flushed but still exists locally, restart the work to drop it after the
- * local retention period expires.
+ * If the object is flushed but still exists locally, restart the work to remove it after
+ * the local retention period expires.
*/
if (exist) {